Documentation
¶
Overview ¶
.env file reader for go.
`envReader "github.com/udan-jayanith/envReader"`
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Get ¶ added in v1.1.0
Get returns the value for a given key.
If the .env file hasn't been read yet, Get will read the .env file and then return the value for the given key.
func SetEnvVars ¶ added in v1.2.1
func SetEnvVars()
SetEnvVars sets environment variables using os.Setenv() for each key-value pair in EnvStruct.
This allows the environment variables to be retrieved using os.Getenv().
Types ¶
Click to show internal directories.
Click to hide internal directories.